--- dlls/iphlpapi/ifenum.c.20050419	2006-01-16 17:33:15.000000000 -0800
+++ dlls/iphlpapi/ifenum.c	2006-01-17 10:53:22.000000000 -0800
@@ -100,6 +100,13 @@
 #include <net/if_types.h>
 #endif
 
+// todo - muse
+#define HAVE_IFADDRS_H
+#ifdef HAVE_IFADDRS_H
+#include <ifaddrs.h>
+#endif
+// todo - end
+
 #include "ifenum.h"
 
 #ifdef HAVE_STRUCT_SOCKADDR_SA_LEN
@@ -184,40 +191,6 @@
   return map;
 }
 
-static int isLoopbackInterface(int fd, const char *name)
-{
-  int ret = 0;
-
-  if (name) {
-    struct ifreq ifr;
-
-    lstrcpynA(ifr.ifr_name, name, IFNAMSIZ);
-    if (ioctl(fd, SIOCGIFFLAGS, &ifr) == 0)
-      ret = ifr.ifr_flags & IFF_LOOPBACK;
-  }
-  return ret;
-}
-
-static void countInterfaces(int fd, caddr_t buf, size_t len)
-{
-  caddr_t ifPtr = buf;
-  DWORD numNonLoopbackInterfaces = 0, numLoopbackInterfaces = 0;
-
-  while (ifPtr && ifPtr < buf + len) {
-    struct ifreq *ifr = (struct ifreq *)ifPtr;
-
-    if (isLoopbackInterface(fd, ifr->ifr_name))
-      numLoopbackInterfaces++;
-    else
-      numNonLoopbackInterfaces++;
-    ifPtr += ifreq_len(ifr);
-  }
-  gNonLoopbackInterfaceMap = sizeMap(gNonLoopbackInterfaceMap,
-   numNonLoopbackInterfaces);
-  gLoopbackInterfaceMap = sizeMap(gLoopbackInterfaceMap,
-   numLoopbackInterfaces);
-}
-
 /* Stores the name in the given map, and increments the map's numInterfaces
  * member if stored successfully.  Will store in the same slot as previously if
  * usedLastPass is set, otherwise will store in a new slot.
@@ -272,6 +245,89 @@
   }
 }
 
+// todo - muse
+#if defined(HAVE_IFADDRS_H)
+static void enumerateInterfaces(void)
+{
+  struct ifaddrs* interfaces;
+  
+  if (getifaddrs(&interfaces) != -1) {
+    int nonLoopbacks;
+    int loopbacks;
+    struct ifaddrs* ifa;
+
+    EnterCriticalSection(&mapCS);
+
+    /* count interfaces */
+    nonLoopbacks = 0;
+    loopbacks = 0;
+    for (ifa = interfaces; ifa; ifa = ifa->ifa_next) {
+      if (ifa->ifa_flags & IFF_LOOPBACK)
+        loopbacks++;
+      else
+        nonLoopbacks++;
+    }
+
+    gNonLoopbackInterfaceMap = sizeMap(gNonLoopbackInterfaceMap,
+     nonLoopbacks);
+    gLoopbackInterfaceMap = sizeMap(gLoopbackInterfaceMap,
+     loopbacks);
+
+    markOldInterfaces(gNonLoopbackInterfaceMap);
+    markOldInterfaces(gLoopbackInterfaceMap);
+
+    /* add table entries for them them */
+    for (ifa = interfaces; ifa; ifa = ifa->ifa_next) {
+      if (ifa->ifa_flags & IFF_LOOPBACK)
+        storeInterfaceInMap(gLoopbackInterfaceMap, ifa->ifa_name);
+      else
+        storeInterfaceInMap(gNonLoopbackInterfaceMap, ifa->ifa_name);
+    }
+
+    LeaveCriticalSection(&mapCS);
+
+    freeifaddrs(interfaces);
+  }
+  else
+    perror("getifaddrs");
+}
+#endif
+// todo - muse
+#if !defined(HAVE_IFADDRS_H)
+static int isLoopbackInterface(int fd, const char *name)
+{
+  int ret = 0;
+
+  if (name) {
+    struct ifreq ifr;
+
+    lstrcpynA(ifr.ifr_name, name, IFNAMSIZ);
+    if (ioctl(fd, SIOCGIFFLAGS, &ifr) == 0)
+      ret = ifr.ifr_flags & IFF_LOOPBACK;
+  }
+  return ret;
+}
+
+static void countInterfaces(int fd, caddr_t buf, size_t len)
+{
+  caddr_t ifPtr = buf;
+  DWORD numNonLoopbackInterfaces = 0, numLoopbackInterfaces = 0;
+
+  while (ifPtr && ifPtr < buf + len) {
+    struct ifreq *ifr = (struct ifreq *)ifPtr;
+
+    if (isLoopbackInterface(fd, ifr->ifr_name))
+      numLoopbackInterfaces++;
+    else
+      numNonLoopbackInterfaces++;
+    ifPtr += ifreq_len(ifr);
+  }
+  gNonLoopbackInterfaceMap = sizeMap(gNonLoopbackInterfaceMap,
+   numNonLoopbackInterfaces);
+  gLoopbackInterfaceMap = sizeMap(gLoopbackInterfaceMap,
+   numLoopbackInterfaces);
+}
+
 static void classifyInterfaces(int fd, caddr_t buf, size_t len)
 {
   caddr_t ifPtr = buf;
@@ -335,6 +391,8 @@
     close(fd);
   }
 }
+#endif
+// todo - muse
 
 DWORD getNumNonLoopbackInterfaces(void)
 {
